@@ -19,6 +19,8 @@ logger = logging.getLogger(__name__)
 
 FIELD_ID = "id"
 FIELD_LAST_MODIFIED = "last_modified"
+# Source collection fields to be copied to destination.
+PUBLISHED_COLLECTION_FIELDS = ("schema", "sort", "displayFields", "attachment")
 
 
 class TRACKING_FIELDS(Enum):
@@ -223,7 +225,11 @@ class LocalUpdater(object):
         if refresh_last_edit:
             current_userid = request.prefixed_userid
             current_date = datetime.datetime.now(datetime.timezone.utc).isoformat()
-            attrs = {"status": STATUS.SIGNED.value}
+            attrs = {
+                "status": STATUS.SIGNED.value,
+                "last_editor_comment": "",
+                "last_reviewer_comment": "",
+            }
             attrs[TRACKING_FIELDS.LAST_EDIT_BY.value] = current_userid
             attrs[TRACKING_FIELDS.LAST_EDIT_DATE.value] = current_date
             self._update_source_attributes(request, **attrs)
@@ -367,8 +373,7 @@ class LocalUpdater(object):
         new_collection = dict(**collection_record)
         new_collection.pop(FIELD_LAST_MODIFIED, None)
         new_collection["signature"] = signature
-        # Copy some Kinto-Admin UI attributes from source to destination.
-        for attr in ("sort", "displayFields", "attachment"):
+        for attr in PUBLISHED_COLLECTION_FIELDS:
             if attr in source_attributes:
                 new_collection.setdefault(attr, source_attributes[attr])
 
@@ -409,6 +414,9 @@ class LocalUpdater(object):
         if status == STATUS.TO_REVIEW:
             attrs[TRACKING_FIELDS.LAST_REVIEW_REQUEST_BY.value] = current_userid
             attrs[TRACKING_FIELDS.LAST_REVIEW_REQUEST_DATE.value] = current_date
+            # Make sure we reset the review comments if none is specified.
+            if "last_editor_comment" not in request.validated["body"].get("data", {}):
+                attrs["last_editor_comment"] = ""
         if status == STATUS.SIGNED:
             if old_status != STATUS.SIGNED:
                 # Do not keep track of reviewer when refreshing signature.
