@@ -45,7 +45,7 @@ class PostgresWebTest(BaseWebTest):
         settings = super().get_app_settings(extras)
 
         settings["storage_backend"] = "kinto.core.storage.postgresql"
-        db = "postgres://postgres:postgres@localhost/testdb"
+        db = "postgresql://postgres:postgres@localhost/testdb"
         settings["storage_url"] = db
         settings["permission_backend"] = "kinto.core.permission.postgresql"
         settings["permission_url"] = db
@@ -248,7 +248,7 @@ class ForceReviewTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.headers)
         assert resp.json["data"]["status"] == "work-in-progress"
 
-    def test_passing_from_signed_to_to_sign_is_allowed(self):
+    def test_passing_from_signed_to_to_sign_is_not_allowed(self):
         """This is useful when the x5u certificate changed and you want
         to retrigger a new signature."""
         self.app.patch_json(
@@ -260,11 +260,13 @@ class ForceReviewTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.other_headers)
         assert resp.json["data"]["status"] == "signed"
 
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.other_headers
+        resp = self.app.patch_json(
+            self.source_collection,
+            {"data": {"status": "to-sign"}},
+            headers=self.other_headers,
+            status=400,
         )
-        resp = self.app.get(self.source_collection, headers=self.headers)
-        assert resp.json["data"]["status"] == "signed"
+        assert resp.json["message"] == "Collection already signed"
 
     def test_editor_cannot_be_reviewer(self):
         self.app.patch_json(
@@ -334,18 +336,6 @@ class RefreshSignatureTest(SignoffWebTest, unittest.TestCase):
         after = resp.headers["ETag"]
         assert before == after
 
-    def test_old_resign_does_not_bump_destination_timestamp(self):
-        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
-        before = resp.headers["ETag"]
-
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
-        )
-
-        resp = self.app.head(self.destination_collection + "/records", headers=self.headers)
-        after = resp.headers["ETag"]
-        assert before == after
-
     def test_editor_can_retrigger_a_signature(self):
         # Editor retriggers a signature, without going through review.
         self.app.patch_json(
@@ -355,13 +345,6 @@ class RefreshSignatureTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.headers)
         assert resp.json["data"]["status"] == "signed"
 
-        # Old way (status: to-sign)
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
-        )
-        resp = self.app.get(self.source_collection, headers=self.headers)
-        assert resp.json["data"]["status"] == "signed"
-
     def test_reviewer_can_retrigger_a_signature(self):
         self.app.patch_json(
             self.source_collection, {"data": {"status": "to-resign"}}, headers=self.other_headers
@@ -369,13 +352,6 @@ class RefreshSignatureTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.headers)
         assert resp.json["data"]["status"] == "signed"
 
-        # Old way (status: to-sign)
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.other_headers
-        )
-        resp = self.app.get(self.source_collection, headers=self.headers)
-        assert resp.json["data"]["status"] == "signed"
-
     def test_if_resign_fails_signature_is_rolledback(self):
         self.mocked_autograph.post.side_effect = ValueError("Boom!")
 
@@ -403,13 +379,6 @@ class RefreshSignatureTest(SignoffWebTest, unittest.TestCase):
         resp = self.app.get(self.source_collection, headers=self.headers)
         assert resp.json["data"]["status"] == "signed"
 
-        # Old way (status: to-sign)
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=writer_headers
-        )
-        resp = self.app.get(self.source_collection, headers=self.headers)
-        assert resp.json["data"]["status"] == "signed"
-
     def test_signature_can_be_refreshed_with_pending_changes(self):
         self.app.post_json(
             self.source_collection + "/records",
@@ -616,6 +585,26 @@ class RollbackChangesTest(SignoffWebTest, unittest.TestCase):
         after_date = resp.json["data"]["last_edit_date"]
         assert before_date != after_date
 
+    def test_comments_are_reset(self):
+        self.app.patch_json(
+            self.source_collection,
+            {
+                "data": {
+                    "last_editor_comment": "please check that",
+                    "last_reviewer_comment": "looks good",
+                }
+            },
+            headers=self.headers,
+        )
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-rollback"}}, headers=self.headers
+        )
+
+        resp = self.app.get(self.source_collection, headers=self.headers)
+        assert resp.json["data"]["last_editor_comment"] == ""
+        assert resp.json["data"]["last_reviewer_comment"] == ""
+
     def test_recreates_deleted_record(self):
         resp = self.app.delete(
             self.source_collection + "/records?_limit=1&_sort=last_modified", headers=self.headers
@@ -915,12 +904,19 @@ class PreviewCollectionTest(SignoffWebTest, unittest.TestCase):
     def test_the_preview_collection_receives_kinto_admin_ui_attributes(self):
         self.app.patch_json(
             self.source_collection,
-            {"data": {"status": "to-review", "displayFields": ["age"]}},
+            {
+                "data": {
+                    "status": "to-review",
+                    "displayFields": ["age"],
+                    "schema": {"type": "object"},
+                }
+            },
             headers=self.headers,
         )
 
         resp = self.app.get(self.preview_collection, headers=self.headers)
         assert resp.json["data"]["displayFields"] == ["age"]
+        assert "schema" in resp.json["data"]
 
     def test_the_preview_collection_is_also_resigned(self):
         self.app.patch_json(
@@ -949,15 +945,6 @@ class PreviewCollectionTest(SignoffWebTest, unittest.TestCase):
         signature_preview_after = resp.json["data"]["signature"]
         assert signature_preview_before != signature_preview_after
 
-        # Resign the old way.
-        self.app.patch_json(
-            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
-        )
-        resp = self.app.get(self.preview_collection, headers=self.headers)
-        signature_preview_before = signature_preview_after
-        signature_preview_after = resp.json["data"]["signature"]
-        assert signature_preview_before != signature_preview_after
-
     def test_the_preview_collection_is_emptied_when_source_records_are_deleted(self):
         self.app.patch_json(
             self.source_collection, {"data": {"status": "to-review"}}, headers=self.headers
@@ -995,6 +982,25 @@ class PreviewCollectionTest(SignoffWebTest, unittest.TestCase):
         records = resp.json["data"]
         assert len(records) == 0
 
+    def test_last_editor_comment_are_reset_on_review(self):
+        self.app.patch_json(
+            self.source_collection,
+            {
+                "data": {
+                    "last_editor_comment": "please check that",
+                    "last_reviewer_comment": "looks good",
+                }
+            },
+            headers=self.headers,
+        )
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-review"}}, headers=self.headers
+        )
+
+        resp = self.app.get(self.source_collection, headers=self.headers)
+        assert resp.json["data"]["last_editor_comment"] == ""
+
 
 class CollectionDelete(SignoffWebTest, unittest.TestCase):
     @classmethod
